@@ -27,6 +27,17 @@ impl Default for GeoInfo {
 }
 
 impl GeoInfo {
+    /// Create information from a vector.
+    pub fn from_vector(start: [f64; 2], end: [f64; 2]) -> Self {
+        let dx = end[0] - start[0];
+        let dy = end[1] - start[1];
+        Self {
+            rot: atan2(dy, dx),
+            scale: hypot(dx, dy),
+            center: start,
+        }
+    }
+
     /// An chain operator on two information.
     ///
     /// It can be used on a not normalized contour `a` transforming to another geometry `b`.
@@ -44,7 +55,7 @@ impl GeoInfo {
     ///
     /// The `Efd` type can called with [`Efd::to`](crate::Efd::to).
     pub fn to(&self, rhs: &Self) -> Self {
-        let mut rot = -self.rot + rhs.rot;
+        let mut rot = rhs.rot - self.rot;
         if sin(rot) < 0. {
             rot += copysign(FRAC_2_PI, cos(rot));
         }
@@ -63,6 +74,8 @@ impl GeoInfo {
 
     /// Transform a contour with this information.
     ///
+    /// This function rotates first, then translates.
+    ///
     /// ```
     /// # use efd::Efd;
     /// # use efd::tests::{PATH, TARGET};
@@ -77,16 +90,14 @@ impl GeoInfo {
     ///
     /// The `Efd` type can called with [`Efd::transform`](crate::Efd::transform).
     pub fn transform(&self, curve: &[[f64; 2]]) -> Vec<[f64; 2]> {
-        let mut out = Vec::with_capacity(curve.len());
-        for c in curve {
-            let angle = self.rot;
+        let mut out = curve.to_vec();
+        for c in out.iter_mut() {
             let dx = c[0] * self.scale;
             let dy = c[1] * self.scale;
-            let c = cos(angle);
-            let s = sin(angle);
-            let x = self.center[0] + dx * c - dy * s;
-            let y = self.center[1] + dx * s + dy * c;
-            out.push([x, y]);
+            let ca = cos(self.rot);
+            let sa = sin(self.rot);
+            c[0] = self.center[0] + dx * ca - dy * sa;
+            c[1] = self.center[1] + dx * sa + dy * ca;
         }
         out
     }
